@@ -162,6 +162,7 @@ class Report(models.Model):
     summary = models.CharField(max_length=20, choices=SUMMARY_CHOICES)
     prefixes = models.ManyToManyField(Prefix)
     active = models.BooleanField(default=False)
+    recipient = models.EmailField(max_length=254, null=True)
 
     def __unicode__(self):
         return unicode(self.name)
@@ -433,7 +434,7 @@ def _get_oops_tuple(oops):
     # Trim most_expensive_statements to 200 characters
     if most_expensive_statement is not None:
         most_expensive_statement = conform(most_expensive_statement, 200)
-    url = conform(oops.get('url') or '', MAX_URL_LEN)
+    url = oops.get('url') or ''
     if type(url) is unicode:
         # We have gotten a ringer, URL's are bytestrings. Encode to UTF8 to get
         # a bytestring and urllib.quote to get a url.
@@ -447,6 +448,7 @@ def _get_oops_tuple(oops):
             # to quote it to make it a valid URL - this is better than
             # rejecting the OOPS, or having a URL that isn't in the DB.
             url = urllib.quote(url)
+    url = conform(url, MAX_URL_LEN)
 
     informational = oops.get('informational', 'False').lower() == 'true'
     oops_date = oops.get('time')
